@@ -14,8 +14,21 @@ data("housing", package = "MASS")
 design <- svydesign(ids = ~1, weights = ~Freq, data = housing)
 fit <- svyolr(Sat ~ Infl + Type + Cont, design = design)
 
+data("api", package = "survey")
+dstrat <- svydesign(
+    id = ~1,
+    strata = ~stype,
+    weights = ~pw,
+    data = apistrat,
+    fpc = ~fpc)
+fit_svyglm <- svyglm(
+    formula = sch.wide ~ ell + meals + mobility,
+    design = dstrat,
+    family = quasibinomial())
+
+
 test_that("survey tidier arguments", {
-  #check_arguments(tidy.svyolr)
+  # check_arguments(tidy.svyolr)
   check_arguments(glance.svyolr)
 })
 
@@ -30,25 +43,16 @@ test_that("glance.svyolr", {
   check_dims(gl, 1, 3)
 })
 
+test_that("glance.svyglm: make sure `nobs` is there", {
+  gl <- glance(fit_svyglm)
+  check_glance_outputs(gl)
+  check_dims(gl, 1, 7)
+  expect_true("nobs" %in% colnames(glance(fit_svyglm)))
+})
+
 test_that("conf.int merging regression test (#804)", {
-  data(api)
-
-  dstrat <- svydesign(
-    id = ~1,
-    strata = ~stype,
-    weights = ~pw,
-    data = apistrat,
-    fpc = ~fpc
-  )
-
-  mod <- svyglm(
-    formula = sch.wide ~ ell + meals + mobility,
-    design = dstrat,
-    family = quasibinomial()
-  )
-
   expect_error(
-    tidy(mod, conf.int = TRUE),
+    tidy(fit_svyglm, conf.int = TRUE),
     NA
   )
 })
